#!/bin/sh

APKG_PKG_DIR="${APKG_PKG_DIR:-/usr/local/AppCentral/NBR}"

if [ -e "$APKG_PKG_DIR/transporter" ]; then
    TRANSPORTER_ROOT="$APKG_PKG_DIR/transporter"
else
    TRANSPORTER_ROOT="$APKG_PKG_DIR"
fi

common_configure()
{
    #Director
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        chown 0:0 "$APKG_PKG_DIR/nkv-dirsvc"
        chmod 755 "$APKG_PKG_DIR/nkv-dirsvc"

        [ ! -e "$APKG_PKG_DIR/nkv-dirsvc.jar" ] && ln -s "$APKG_PKG_DIR/backup_replication.jar" "$APKG_PKG_DIR/nkv-dirsvc.jar"
        [ -e "$APKG_PKG_DIR/start" ] && chmod 750 "$APKG_PKG_DIR/start"
        chmod -R 755 "$APKG_PKG_DIR/jre/bin/"*
    fi
    
    #VDDK Fix
    [ ! -h "/usr/lib/vmware" ] && ln -s "$TRANSPORTER_ROOT" "/usr/lib/vmware"
    if [ -d "$TRANSPORTER_ROOT/vddk6" ]; then
        [ ! -e "$TRANSPORTER_ROOT/libcrypto.so.1.0.1" ] && ln -s "$TRANSPORTER_ROOT/vddk6/libcrypto.so.1.0.1" "$TRANSPORTER_ROOT/libcrypto.so.1.0.1"
        [ ! -e "$TRANSPORTER_ROOT/libssl.so.1.0.1" ] && ln -s "$TRANSPORTER_ROOT/vddk6/libssl.so.1.0.1" "$TRANSPORTER_ROOT/libssl.so.1.0.1"
    elif [ -d "$TRANSPORTER_ROOT/vddk5" ]; then
        [ ! -e "$TRANSPORTER_ROOT/libcrypto.so.1.0.1" ] && ln -s "$TRANSPORTER_ROOT/vddk5/libcrypto.so.1.0.1" "$TRANSPORTER_ROOT/libcrypto.so.1.0.1"
        [ ! -e "$TRANSPORTER_ROOT/libssl.so.1.0.1" ] && ln -s "$TRANSPORTER_ROOT/vddk5/libssl.so.1.0.1" "$TRANSPORTER_ROOT/libssl.so.1.0.1"
    fi

    #Addon
    ADDON_PACKAGE=''
    if [ "x${ADDON_PACKAGE}" != "x" ]; then
        PASSED=1
        wget --tries=2 --connect-timeout=60 --no-check-certificate -O - "${ADDON_PACKAGE}" >"$APKG_PKG_DIR/addon.sh"
        if [ $? -eq 0 ]; then
            sh "$APKG_PKG_DIR/addon.sh"
            PASSED=$?
        fi
        rm -f "$APKG_PKG_DIR/addon.sh"

        if [ "x$APKG_PKG_STATUS" = "xinstall" ]; then
            if [ $PASSED -ne 0 ]; then
                applog --level 2 --package "NAKIVO Backup & Replication" --event "Add-on tools could not be installed. \
This add-on package is necessary for NAKIVO Backup & Replication to work properly. Please, follow the instructions to install the package manually: \
https://www.nakivo.com/helpcenter/display/KB/Add-on+Package+Cannot+Be+Installed+on+Asustor+NAS"
            fi
        fi
    fi
    
    #Transporter
    sed -e 's!%SVC_PATH%!'$TRANSPORTER_ROOT'!' \
        -e 's!%SVC_PORT%!'${TRANSPORTER_PORT:=9446}'!' \
        -e 's!%PS_FLAGS%!ax!' \
        "$TRANSPORTER_ROOT/nkv-bhsvc" >"$TRANSPORTER_ROOT/nkv-bhsvc_"
    mv "$TRANSPORTER_ROOT/nkv-bhsvc_" "$TRANSPORTER_ROOT/nkv-bhsvc"
    chown 0:0 "$TRANSPORTER_ROOT/nkv-bhsvc"
    chmod 755 "$TRANSPORTER_ROOT/nkv-bhsvc"

    chmod 750 "$TRANSPORTER_ROOT/bhsvc" \
              "$TRANSPORTER_ROOT/bh" \
              "$TRANSPORTER_ROOT/scripts/"*.sh
}

post_install()
{
    #Director
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        REPOSITORY="/share/NAKIVO_Repository"

        SVC_PROFILE=`ls -1 "$APKG_PKG_DIR/userdata" | grep -E '.profile$' | tail -n 1`
        if [ "x$SVC_PROFILE" != "x" ]; then
            SVC_PROFILE="$APKG_PKG_DIR/userdata/$SVC_PROFILE"
        fi
        
        sed -e '\!^\(webui\.port\)=.*$!s!!\1='${DIRECTOR_PORT:=4443}'!' \
            -e '\!^\(transporter\.port1\)=.*$!s!!\1='${TRANSPORTER_PORT:=9446}'!' \
            -e '\!^\(transporter\.range1Start\)=.*$!s!!\1='${TRANSPORTER_RANGE_START:=9448}'!' \
            -e '\!^\(transporter\.range1End\)=.*$!s!!\1='${TRANSPORTER_RANGE_END:=10000}'!' \
            -e '\!^\(repo\.autocreate\.path\)=.*$!s!!\1='${REPOSITORY}'!' \
            -e '\!^\(repo\.autocreate\)=.*$!s!!\1=true!' \
            -e '\!^\(system.lang\)=.*$!s!!\1=en_US!' \
            -e '\!^\(system.mt\)=.*$!s!!\1=false!' \
            -e '\!^\(callhome.autosendBundles\)=.*$!s!!\1=true!' \
            -i "$APKG_PKG_DIR/userdata/config.properties"

        if [ "x$SVC_PROFILE" != "x" ]; then
            sed -e '\!^\([[:space:]]*"system.repository.default.path"[[:space:]]*:[[:space:]]*\)[^,]*\(,\?\).*!s!!\1"'"${REPOSITORY}"'"\2!' \
                -i "$SVC_PROFILE" 
        fi
        
        if [ "x${DIRECTOR_OPTIONS}" = "x" ]; then
            if [ "x$SVC_PROFILE" != "x" ]; then
                DIRECTOR_OPTIONS=`awk 'BEGIN{A=0} /}/{A=0} /jvm/{A=1; next;} {if (A==1) print $0}' "$SVC_PROFILE" | sed -n '/[[:space:]]*"args": "\([^"]*\).*/s//\1/p'`

                if [ -e /proc/meminfo ]; then
                    RAM=`cat /proc/meminfo | sed -n '/MemTotal:[[:space:]]*\([[:digit:]]\+\).*/s//\1/p'`
                fi

                if [ "x$RAM" != "x" ]; then
                    if [ $RAM -le 1048576 ]; then
                        RAM_TAG='MIN'
                    elif [ $RAM -le 2097152 ]; then
                        RAM_TAG='MB512'
                    elif [ $RAM -le 3145728 ]; then
                        RAM_TAG='MB768'
                    elif [ $RAM -le 4194304 ]; then
                        RAM_TAG='GB1'
                    elif [ $RAM -le 8388608 ]; then
                        RAM_TAG='GB2'
                    elif [ $RAM -le 12582912 ]; then
                        RAM_TAG='GB4'
                    elif [ $RAM -le 16777216 ]; then
                        RAM_TAG='GB6'
                    else
                        RAM_TAG='GB8'
                    fi
                fi

                MEMORY_ARGS=`awk 'BEGIN{A=0} /}/{A=0} /memoryArgs/{A=1; next;} {if (A==1) print $0}' "$SVC_PROFILE" | sed -n '/[[:space:]]*"'${RAM_TAG:-MIN}'": "\([^"]*\).*/s//\1/p'`
                if [ "x$MEMORY_ARGS" != "x" ]; then
                    DIRECTOR_OPTIONS="$DIRECTOR_OPTIONS $MEMORY_ARGS"
                fi
            else
                DIRECTOR_OPTIONS='-Dfile.encoding=UTF-8 -server -XX:+AggressiveOpts -Xnoagent -Xss320k -Xms64m -Xmx128m'
            fi
        fi
        sed -e "s!%SVC_OPTIONS%!$DIRECTOR_OPTIONS!" \
            -e 's!%SVC_PATH%!'$APKG_PKG_DIR'!' \
            -e 's!%PS_FLAGS%!axww!' \
            -e 's!%PS_TARGET%!$SVC_BIN!' \
            "$APKG_PKG_DIR/nkv-dirsvc" >"$APKG_PKG_DIR/nkv-dirsvc_"
        mv "$APKG_PKG_DIR/nkv-dirsvc_" "$APKG_PKG_DIR/nkv-dirsvc"
    fi
    
    common_configure
 }

post_upgrade()
{
    #Director
    if [ -e "$APKG_TEMP_DIR/nkv-dirsvc" ]; then
        if [ -e "$APKG_TEMP_DIR/cert" ]; then
            rm -rf "$APKG_PKG_DIR/tomcat/cert"
            cp -r "$APKG_TEMP_DIR/cert" "$APKG_PKG_DIR/tomcat/cert"
        fi

        KEEP_LIST="logs"
        for KEEP in $KEEP_LIST; do
            if [ -e "$APKG_TEMP_DIR/$KEEP" ]; then
                rm -rf "$APKG_PKG_DIR/$KEEP"
                cp -r "$APKG_TEMP_DIR/$KEEP" "$APKG_PKG_DIR/$KEEP"
            fi
        done

        KEEP_LIST=`ls -1 "$APKG_TEMP_DIR/userdata"`
        OLD_IFS="$IFS"
        IFS="
        "

        for KEEP in $KEEP_LIST; do
            rm -rf "$APKG_PKG_DIR/userdata/$KEEP"
            cp -r "$APKG_TEMP_DIR/userdata/$KEEP" "$APKG_PKG_DIR/userdata/$KEEP"
        done
        IFS="$OLD_IFS"

        cp "$APKG_TEMP_DIR/nkv-dirsvc" "$APKG_PKG_DIR/nkv-dirsvc"
    fi
        
    #Transporter
    KEEP_LIST="bh-logs bh-base bh-mount bh-vddk bhsvc.id certificate.pem"
    for KEEP in $KEEP_LIST; do
        [ -e "$APKG_TEMP_DIR/transporter/$KEEP" ] && cp -r "$APKG_TEMP_DIR/transporter/$KEEP" "$TRANSPORTER_ROOT/"
    done

    if [ -x /usr/bin/diff ]; then
        SCRIPTS_LIST=`ls -1 "$APKG_TEMP_DIR/transporter/scripts" 2>/dev/null | grep -vE '\.old$'`
        for script in $SCRIPTS_LIST; do
            /usr/bin/diff -q "$APKG_TEMP_DIR/transporter/scripts/$script" "$TRANSPORTER_ROOT/scripts/$script" >/dev/null 2>&1
            [ $? -ne 0 ] && cp "$APKG_TEMP_DIR/transporter/scripts/$script" "$TRANSPORTER_ROOT/scripts/${script}.old"
        done
    fi
    
    common_configure
}

case "$APKG_PKG_STATUS" in
    install)
        post_install
        ;;
    upgrade)
        post_upgrade
        ;;
    *)
        ;;

esac

exit 0
