#!/bin/sh

APKG_PKG_DIR="${APKG_PKG_DIR:-/usr/local/AppCentral/NBR}"

if [ -e "$APKG_PKG_DIR/transporter" ]; then
    TRANSPORTER_ROOT="$APKG_PKG_DIR/transporter"
else
    TRANSPORTER_ROOT="$APKG_PKG_DIR"
fi

pre_upgrade()
{
    CONFIG="$APKG_PKG_DIR/userdata/config.properties"

    #Update forbidden
    if ( false ); then
        applog --level 2 --package "NAKIVO Backup & Replication" --event "An older version is installed and cannot be updated with this Beta installer. \
Beta versions of the software are intended for testing purposes and should not be used in a production environment. \
Please install the Beta version on a separate machine."
        exit 1
    fi

    #Maintenance
    if ( true ); then
        if [ -e "$CONFIG" ]; then
           PRODUCT_MED=`sed -n '\!^med=\(.*\)$!s!!\1!p' "$CONFIG" 2>/dev/null`
        fi
        
        if [ "x${PRODUCT_MED}" != "x" -a ${PRODUCT_MED:-0} -lt 1563753600000 ]; then
            applog --level 2 --package "NAKIVO Backup & Replication" --event "The update cannot be started. The maintenance has ended. \
You are no longer eligible for technical support and software updates. \
Contact sales@nakivo.com to renew the maintenance."
            exit 1
        fi
    fi
    
    #Version update check
    if [ -e "$APKG_PKG_DIR/userdata/version" -a -e "$APKG_PKG_DIR/userdata/db/version" ]; then
        MAJOR=`cat "$APKG_PKG_DIR/userdata/version"`
        BUILD=`echo "$MAJOR" | cut -d . -f 4`
        if [ "x$BUILD" != "x" ]; then
            curver=`echo "$MAJOR" | cut -d . -f 1,2,3`
            curbuild="$BUILD"
        else
            BUILD=`cat "$APKG_PKG_DIR/userdata/db/version"`
            if [ "x$BUILD" != "x" ]; then
                curver="$MAJOR"
                curbuild="$BUILD"
            fi
        fi
    fi
    if [ "x${curver}" != "x" -a "x${curbuild}" != "x" ]; then
        newver=`echo "9.0.0.34278" | cut -d '.' -f 1,2,3`    
        newbuild=`echo "9.0.0.34278" | cut -d '.' -f 4`
        curmajor=`echo $curver | cut -d '.' -f 1`
        if [ $curmajor -lt 8 -o \
             `expr "$newver" \< "$curver"` -gt 0 -o \
             $curbuild -eq 24992 -o \
             $curbuild -eq 27551 -o \
             $curbuild -eq 31961 -o \
             $curbuild -eq 33580 ]; then
            applog --level 2 --package "NAKIVO Backup & Replication" --event "Update of current version is not supported (ver. $curver.$curbuild)."
            exit 1
        elif [ "$newver" = "$curver" -a $newbuild -lt $curbuild ]; then
            applog --level 2 --package "NAKIVO Backup & Replication" --event "Update of current version is not supported (ver. $curver.$curbuild)."
            exit 1
        fi
    fi

    #Director
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        KEEP_LIST="userdata logs tomcat/cert"
        for KEEP in $KEEP_LIST; do
            if [ -e "$APKG_PKG_DIR/$KEEP" ]; then
                rm -rf "$APKG_TEMP_DIR/$KEEP" 2>/dev/null
                cp -r "$APKG_PKG_DIR/$KEEP" "$APKG_TEMP_DIR/$KEEP"
            fi
        done

        #backup copy
        cp "$APKG_PKG_DIR/nkv-dirsvc" "$APKG_TEMP_DIR/nkv-dirsvc"
    fi
    
    #Transporter
    if ls -1 "$TRANSPORTER_ROOT/bh-logs" 2>/dev/null | grep -qE "\.log$"; then
        ARCHIVE=`date '+bh-logs.%F-%H:%M:%S.tgz'`
        tar --force-local -czf "$TRANSPORTER_ROOT/bh-logs/$ARCHIVE" -C "$TRANSPORTER_ROOT/bh-logs" --exclude='*.tgz' . 2>/dev/null
    fi

    mkdir -p "$APKG_TEMP_DIR/transporter"
    KEEP_LIST="scripts bh-logs bh-base bh-mount bh-vddk bhsvc.id certificate.pem"
    for KEEP in $KEEP_LIST; do
        [ -e "$TRANSPORTER_ROOT/$KEEP" ] && cp -r "$TRANSPORTER_ROOT/$KEEP" "$APKG_TEMP_DIR/transporter/"
    done
}

case "$APKG_PKG_STATUS" in
    install)
        ;;
    upgrade)
        pre_upgrade
        ;;
    *)
        ;;

esac

exit 0
