#!/bin/sh

APKG_PKG_DIR="${APKG_PKG_DIR:-/usr/local/AppCentral/NBR}"

if [ -e "$APKG_PKG_DIR/transporter" ]; then
    TRANSPORTER_ROOT="$APKG_PKG_DIR/transporter"
else
    TRANSPORTER_ROOT="$APKG_PKG_DIR"
fi

start()
{
    #patch open-iscsi
    for MODULE in scsi_transport_iscsi libiscsi libiscsi_tcp iscsi_tcp; do
        ( lsmod | grep -qE "^$MODULE " ) || insmod "/usr/builtin/lib/modules/${MODULE}.ko" >/dev/null 2>&1
    done
    [ ! -e /sbin/iscsid ] && ln -sf /usr/builtin/sbin/iscsid /sbin/iscsid
    [ ! -e /etc/iscsi ] && mkdir -p /etc/iscsi
    [ ! -f /etc/iscsi/iscsid.conf ] && cp /usr/builtin/etc.default/iscsid.conf /etc/iscsi/iscsid.conf
    if [ ! -f /etc/iscsi/initiatorname.iscsi ] ; then
        ifconfig | sed -n -e 's/://g' -e '/eth.*HWaddr[[:space:]]*\([0-9a-fA-F]\+\)[[:space:]]*$/s//InitiatorName=iqn.2005-03.org.open-iscsi:\1/p' | head -n 1 >/etc/iscsi/initiatorname.iscsi
        chmod 600 /etc/iscsi/initiatorname.iscsi
    fi

    #enable ntfs support
    for MODULE in jnl ufsd; do
        ( lsmod | grep -qE "^$MODULE " ) || insmod "/usr/builtin/lib/modules/${MODULE}.ko" >/dev/null 2>&1
    done
    
    #VDDK Fix
    [ ! -h "/usr/lib/vmware" ] && ln -s "$TRANSPORTER_ROOT" "/usr/lib/vmware"
    
    #Transporter
    "$TRANSPORTER_ROOT/nkv-bhsvc" start
    RESULT=$?
    if [ $RESULT -ne 0 ]; then
        echo "Failed."
        exit $RESULT
    fi

    #Director
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        "$APKG_PKG_DIR/nkv-dirsvc" start
        RESULT=$?
        if [ $RESULT -ne 0 ]; then
            echo "Failed."
            exit $RESULT
        fi
    fi
    
    return 0
}

stop()
{
    #Director
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        "$APKG_PKG_DIR/nkv-dirsvc" stop
        RESULT=$?
        if [ $RESULT -ne 0 ]; then
            echo "Failed."
            exit $RESULT
        fi
    fi

    #Transporter
    "$TRANSPORTER_ROOT/nkv-bhsvc" stop
    RESULT=$?
    if [ $RESULT -ne 0 ]; then
        echo "Failed."
        exit $RESULT
    fi
    
    exit 0
}

status()
{
    [ "x$APKG_PKG_DIR" = "x" -a ! -e "$APKG_PKG_DIR" ] && return 150
    
    if [ -e "$APKG_PKG_DIR/nkv-dirsvc" ]; then
        "$APKG_PKG_DIR/nkv-dirsvc" status
        RESULT=$?
        if [ $RESULT -ne 0 ]; then
            return $RESULT
        fi
    fi

    [ ! -e "$TRANSPORTER_ROOT/nkv-bhsvc" ] && return 150
    "$TRANSPORTER_ROOT/nkv-bhsvc" status
    return $RESULT
}

case "$1" in
    'start')
        start
        exit $?
    ;;

    'stop')
        stop
        exit 0
    ;;

    'status')
        status
        exit $?
    ;;
    
    'restart')
        stop
        sleep 2
        start
        exit $?
    ;;

    *)
        echo "usage: $0 start|stop|status"
        exit 1
    ;;
esac
